###########################################################################################################
## Screening for redundant variables for the avoidance of unneccesary measurments in studies on wild birds.
## Produced by Adriaan "Adjan" de Jong, Dept. of Wildlife, Fish, and Environmental Studies,
## Swedish University for Agricultural Sciences, Ume, Sweden. e-mail: adriaan.de.jong@slu.se
## Please feel free to use and modify this script in any possible way.
###########################################################################################################
 
###########################################################################################################
###########################################################################################################
## PART 1. Script used for analyses presented in the Frontiers Veterinary Science manuscripts (subm 411483)
###########################################################################################################
###########################################################################################################
##  
## Startup procedure and linking to libraries. 
## !Some libraries were initially skipped because they interfere with certain functions (mainly "histogram")
## They are activated later.
## The rm(list=ls()) command clears all the registers.

rm(list=ls())
library(lattice)
library(Matrix)
library(lme4)
library(MASS)
library(AICcmodavg)
library(corrplot)
citation("lattice")
citation("Matrix")
citation("lme4")
citation("MASS")
citation("AICcmodavg")
citation("corrplot")

######################################################################################################
## Notes
######################################################################################################
## 1.Input files are tab delimited textfiles with decimal points (not commas).
## 2.Only the "Goose measurements C.text" could have been used, but this would have required selecting
##   appropriate variables for each analysis and renaming the variables (columns) for some. 
##   For simplicity and clarity, I chose to prepare and read separate files.
## 3.Because multiple files are read as dataframes, attach(dataframe.name) statements are used for 
##   individual analysis.
## 4.The "par(mfrom=c(x,x)) commands enable plotting multiple frames in one plot. I have used this 
##   command extensively, just to make sure the setting was right in each individual analysis.
## 5.I have used the " <- NA" command to make sure parameters or vectors were empty before adding new 
##   data. Just to be sure.
######################################################################################################

## Input data with full variable names (no classification variable)
Bean0<-read.table("l://AAStruktur/Sdgs/Subspec PCA/Goose measurements A.txt",header=TRUE,na.strings="NA")
names(Bean0)
Bean0$Teeth <- as.integer(Bean0$Teeth)

## Input data with abbreviated variable names (no classification variable)
Bean00<-read.table("l://AAStruktur/Sdgs/Subspec PCA/Goose measurements B.txt",header=TRUE,na.strings="NA")
names(Bean00)
Bean00$Q <- as.integer(Bean00$Q)

## Input data with with classification variable
Bean1<-read.table("l://AAStruktur/Sdgs/Subspec PCA/Goose measurements C.txt",header=TRUE,na.strings="NA")
names(Bean1)
Bean1$Teeth <- as.integer(Bean1$Teeth)

## Input data with with classification variable but only five explanatory variables. Used in discriminant analysis.
Bean1A<-read.table("l://AAStruktur/Sdgs/Subspec PCA/Goose measurements D.txt",header=TRUE,na.strings="NA")
names(Bean1A)
Bean1A$Teeth <- as.integer(Bean1A$Teeth)

## Input data with with classification variable but only two explanatory variables. Used in discriminant analysis.
Bean1B<-read.table("l://AAStruktur/Sdgs/Subspec PCA/Goose measurements E.txt",header=TRUE,na.strings="NA")
names(Bean1B)
Bean1B$Teeth <- as.integer(Bean1B$Teeth)


######################################################################################################
## SINGLE VARIABLE ANALYSES
######################################################################################################

## Basic statistics. I used a loop for this, but the variables can also be analysed one at a time.
attach(Bean0)
data.output <- NA
data.output= matrix(data=NA, nrow=17, ncol=8)
colnames(data.output)= c("i", "Antal","Minimum","Maximum", "Range", "Median", "Mean", "SD")
rader <- 1

for (i in 1:17)     #  loop for basic statistics per variable
{             # start loop i
  
  col1 <- NA
  col1 <- Bean00[,i]    # set the sample measurement values (column) for each loop
  
  ## Set all support values to NA
  Min00 <- NA
  Max00 <- NA
  Mean00 <- NA
  Median00 <- NA
  SD00 <- NA
  Antal <- NA
  
  ## Do the calculations         
  Min00 <- min(col1)                  
  Max00 <- max(col1)                  
  Range00 <- (Max00 - Min00)
  Mean00 <- mean(col1)                
  Median00 <-  median(col1)          
  SD00  <- sd(col1)                  
  Antal <- length(col1)
  
  data.output[rader , 1] = i            
  data.output[rader , 2] = Antal        
  data.output[rader , 3] = Min00        
  data.output[rader , 4] = Max00          
  data.output[rader , 5] = Range00
  data.output[rader , 6] = Median00   
  data.output[rader , 7] = Mean00             
  data.output[rader , 8] = SD00          
  
  rader <- rader + 1

  
} ## close  loop


View(data.output)
## The data.output result table can be written to a file using: write.table(data.output, "file name.txt")



######################################################################################################
## Histograms
attach(Bean0)
histogram(Bean0$Bill_plus_head, type="count", xlab="Bill plus head (mm)", col="grey")
histogram(Bean0$Bill_height_nail, type="count", xlab="Bill height nail (mm)", col="grey")
histogram(Bean0$Height_lower_mandible, type="count", xlab="Height lower mandible (mm)", col="grey")
histogram(Bean0$Teeth, type="count", breaks=seq(19.5,30.5,1), xlab="Teeth", col="grey")

######################################################################################################


######################################################################################################
## Logistic models and incidence plots for this manuscript
######################################################################################################
par(mfrow=c(2,2))
attach(Bean1)
## Logistic model for Culmen
MinA <- min(Bean1$Culmen)
MaxA <- max(Bean1$Culmen)
Form<-formula(Fabalis~Culmen)
MA<-glm(Form,family=binomial,data=Bean1,na.action=na.omit)
summary(MA)
xv<-seq(MinA,MaxA,0.1)
yv<-predict(MA,list(Culmen=xv),type="response")
plot(Culmen,Fabalis, xlab="Culmen (mm)")  
lines(xv,yv)

## Logistic model for Bill_tip_to_nostril
MinC <- min(Bean1$Bill_tip_to_nostril)
MaxC <- max(Bean1$Bill_tip_to_nostril)
Form<-formula(Fabalis~Bill_tip_to_nostril)
MC<-glm(Form,family=binomial,data=Bean1,na.action=na.omit)
summary(MC)
xv<-seq(MinC,MaxC,0.1)
yv<-predict(MC,list(Bill_tip_to_nostril=xv),type="response")
plot(Bill_tip_to_nostril,Fabalis, xlab="Bill tip to nostril (mm)")  
lines(xv,yv)

## Logistic model for Height lower mandible
MinM <- min(Bean1$Height_lower_mandible)
MaxM <- max(Bean1$Height_lower_mandible)
Form<-formula(Fabalis~Height_lower_mandible)
MM<-glm(Form,family=binomial,data=Bean1,na.action=na.omit)
summary(MM)
xv<-seq(MinM,MaxM,0.01)
yv<-predict(MM,list(Height_lower_mandible=xv),type="response")
plot(Height_lower_mandible,Fabalis, xlab="Height lower mandible (mm)")  
lines(xv,yv)

## Logistic model for Teeth
MinQ <- min(Bean1$Teeth)
MaxQ <- max(Bean1$Teeth)
Form<-formula(Fabalis~Teeth)
MQ<-glm(Form,family=binomial,data=Bean1,na.action=na.omit)
summary(MQ)
xv<-seq(MinQ,MaxQ,0.1)
yv<-predict(MQ,list(Teeth=xv),type="response")
plot(Teeth,Fabalis, xlab="Teeth")  
lines(xv,yv)

par(mfrow=c(1,1))

######################################################################################################
## All logistivs models in short for the AICC values
attach(Bean1)
MA <- glm(Fabalis~Culmen,family=binomial,data=Bean1,na.action=na.omit)
MB <- glm(Fabalis~Lower_mandible,family=binomial,data=Bean1,na.action=na.omit)
MC <- glm(Fabalis~Bill_tip_to_nostril,family=binomial,data=Bean1,na.action=na.omit)
MD <- glm(Fabalis~Bill_plus_head,family=binomial,data=Bean1,na.action=na.omit)
ME <- glm(Fabalis~Head_length,family=binomial,data=Bean1,na.action=na.omit)
MF <- glm(Fabalis~Head_width,family=binomial,data=Bean1,na.action=na.omit)
MG <- glm(Fabalis~Nail_length,family=binomial,data=Bean1,na.action=na.omit)
MH <- glm(Fabalis~Nail_width,family=binomial,data=Bean1,na.action=na.omit)
MI <- glm(Fabalis~Bill_height,family=binomial,data=Bean1,na.action=na.omit)
MJ <- glm(Fabalis~Bill_height_nail,family=binomial,data=Bean1,na.action=na.omit)
MK <- glm(Fabalis~Bill_height_nostril,family=binomial,data=Bean1,na.action=na.omit)
ML <- glm(Fabalis~Bill_width,family=binomial,data=Bean1,na.action=na.omit)
MM <- glm(Fabalis~Height_lower_mandible,family=binomial,data=Bean1,na.action=na.omit)
MN <- glm(Fabalis~Tail,family=binomial,data=Bean1,na.action=na.omit)
MO <- glm(Fabalis~Tarsus,family=binomial,data=Bean1,na.action=na.omit)
MP <- glm(Fabalis~Toe_nail,family=binomial,data=Bean1,na.action=na.omit)
MQ <- glm(Fabalis~Teeth,family=binomial,data=Bean1,na.action=na.omit) ##! this line causes a warning due to the data structure (integer)


##AICc values
AICc(MA, return.K = FALSE, second.ord = TRUE, nobs = NULL, c.hat = 1)
AICc(MB, return.K = FALSE, second.ord = TRUE, nobs = NULL, c.hat = 1)
AICc(MC, return.K = FALSE, second.ord = TRUE, nobs = NULL, c.hat = 1)
AICc(MD, return.K = FALSE, second.ord = TRUE, nobs = NULL, c.hat = 1)
AICc(ME, return.K = FALSE, second.ord = TRUE, nobs = NULL, c.hat = 1)
AICc(MF, return.K = FALSE, second.ord = TRUE, nobs = NULL, c.hat = 1)
AICc(MG, return.K = FALSE, second.ord = TRUE, nobs = NULL, c.hat = 1)
AICc(MH, return.K = FALSE, second.ord = TRUE, nobs = NULL, c.hat = 1)
AICc(MI, return.K = FALSE, second.ord = TRUE, nobs = NULL, c.hat = 1)
AICc(MJ, return.K = FALSE, second.ord = TRUE, nobs = NULL, c.hat = 1)
AICc(MK, return.K = FALSE, second.ord = TRUE, nobs = NULL, c.hat = 1)
AICc(ML, return.K = FALSE, second.ord = TRUE, nobs = NULL, c.hat = 1)
AICc(MM, return.K = FALSE, second.ord = TRUE, nobs = NULL, c.hat = 1)
AICc(MN, return.K = FALSE, second.ord = TRUE, nobs = NULL, c.hat = 1)
AICc(MO, return.K = FALSE, second.ord = TRUE, nobs = NULL, c.hat = 1)
AICc(MP, return.K = FALSE, second.ord = TRUE, nobs = NULL, c.hat = 1)
AICc(MQ, return.K = FALSE, second.ord = TRUE, nobs = NULL, c.hat = 1)
######################################################################################################



######################################################################################################
## Pairwise VARIABLE ANALYSES
######################################################################################################

## Pairs plot with acronym names and smoother
attach(Bean00)
par(mfrow=c(1,1))
pairs(Bean00,panel=panel.smooth)
######################################################################################################

## Correlation matrix with acronym names
attach(Bean00)
par(mfrow=c(1,1))
M02<-cor(Bean00)
corrplot.mixed(M02, lower.col="black", number.cex=0.7)

######################################################################################################
## partitioning (kmeans)
######################################################################################################

attach(Bean1)
par(mfrow=c(2,2))
plot(Bean1$Culmen,Bean1$Height_lower_mandible, col=c(Bean1$Fabalis+1),pch=16, ylab="Height lower mandible (mm)", xlab="Culmen (mm)")
MP2 <- kmeans(data.frame(Culmen,Height_lower_mandible),2)
plot(Bean1$Culmen,Bean1$Height_lower_mandible,col=MP2[[1]],pch=16, ylab="Height lower mandible (mm)", xlab="Culmen (mm)")
table(MP2[[1]], Fabalis)

plot(Bean1$Teeth,Bean1$Height_lower_mandible, col=c(Bean1$Fabalis+1),pch=16, ylab="Height lower mandible (mm)", xlab="Teeth")
MP2 <- kmeans(data.frame(Teeth,Height_lower_mandible),2)
plot(Bean1$Teeth,Bean1$Height_lower_mandible,col=MP2[[1]],pch=16, ylab="Height lower mandible (mm)", xlab="Teeth")
table(MP2[[1]], Fabalis)
par(mfrow=c(1,1))

par(mfrow=c(1,1))

######################################################################################################



######################################################################################################
## Multiple VARIABLE ANALYSES
######################################################################################################

######################################################################################################
### Discriminant analysis with all variables and full variable names
attach(Bean1)
par(mfrow=c(1,1))
MDisc<-lda(Fabalis~.,Bean1)
plot(MDisc, col="grey")
summary(MDisc)
MDisc
######################################################################################################

### Discriminant analysis with only five variables (LD1 > 0.1)
MDisc5<-lda(Fabalis~.,Bean1A)
#plot(MDisc5, col="grey")
MDisc5
######################################################################################################

### Discriminant analysis with only two variables
MDisc2<-lda(Fabalis~.,Bean1B)
plot(MDisc2, col="grey")
MDisc2
######################################################################################################

######################################################################################################
## Model selection with single variable models
######################################################################################################
attach(Bean1)
res.table1<-NA
Cand.set<-list()
Cand.set[[1]]<- glm(Fabalis~Culmen,family=binomial,data=Bean1,na.action=na.omit)
Cand.set[[2]]<- glm(Fabalis~Lower_mandible,family=binomial,data=Bean1,na.action=na.omit)
Cand.set[[3]]<- glm(Fabalis~Bill_tip_to_nostril,family=binomial,data=Bean1,na.action=na.omit)
Cand.set[[4]]<- glm(Fabalis~Bill_plus_head,family=binomial,data=Bean1,na.action=na.omit)
Cand.set[[5]]<- glm(Fabalis~Head_length,family=binomial,data=Bean1,na.action=na.omit)
Cand.set[[6]]<- glm(Fabalis~Head_width,family=binomial,data=Bean1,na.action=na.omit)
Cand.set[[7]]<- glm(Fabalis~Nail_length,family=binomial,data=Bean1,na.action=na.omit)
Cand.set[[8]]<- glm(Fabalis~Nail_width,family=binomial,data=Bean1,na.action=na.omit)
Cand.set[[9]]<- glm(Fabalis~Bill_height,family=binomial,data=Bean1,na.action=na.omit)
Cand.set[[10]]<- glm(Fabalis~Bill_height_nail,family=binomial,data=Bean1,na.action=na.omit)
Cand.set[[11]]<- glm(Fabalis~Bill_height_nostril,family=binomial,data=Bean1,na.action=na.omit)
Cand.set[[12]]<- glm(Fabalis~Bill_width,family=binomial,data=Bean1,na.action=na.omit)
Cand.set[[13]]<- glm(Fabalis~Height_lower_mandible,family=binomial,data=Bean1,na.action=na.omit)
Cand.set[[14]]<- glm(Fabalis~Tail,family=binomial,data=Bean1,na.action=na.omit)
Cand.set[[15]]<- glm(Fabalis~Tarsus,family=binomial,data=Bean1,na.action=na.omit)
Cand.set[[16]]<- glm(Fabalis~Toe_nail,family=binomial,data=Bean1,na.action=na.omit)
Cand.set[[17]]<- glm(Fabalis~Teeth,family=binomial,data=Bean1,na.action=na.omit)
names(Cand.set)<- c("Culmen","Lower mandible","Bill tip to nostril","Bill plus head",
                    "Head length","Head width","Nail length","Nail width","Bill height","Bill height nail",
                    "Bill height nostril","Bill width","Height lower mandible","Tail","Tarsus",
                    "Toe nail","Teeth")
res.table1<-aictab(Cand.set,second.ord=TRUE, nobs=NULL, sort=TRUE, c.hat=1)
print(res.table1, digits=3, LL=TRUE)

######################################################################################################
## Model selection with variable combinations and one composite variable (models 18-21)
######################################################################################################
attach(Bean1)
Bean1$Nail_shape<-(Bean1$Nail_length/Bean1$Nail_width)

res.table2<-NA
Cand.set<-list()
Cand.set[[1]]<- glm(Fabalis~Culmen,family=binomial,data=Bean1,na.action=na.omit)
Cand.set[[2]]<- glm(Fabalis~Lower_mandible,family=binomial,data=Bean1,na.action=na.omit)
Cand.set[[3]]<- glm(Fabalis~Bill_tip_to_nostril,family=binomial,data=Bean1,na.action=na.omit)
Cand.set[[4]]<- glm(Fabalis~Bill_plus_head,family=binomial,data=Bean1,na.action=na.omit)
Cand.set[[5]]<- glm(Fabalis~Head_length,family=binomial,data=Bean1,na.action=na.omit)
Cand.set[[6]]<- glm(Fabalis~Head_width,family=binomial,data=Bean1,na.action=na.omit)
Cand.set[[7]]<- glm(Fabalis~Nail_length,family=binomial,data=Bean1,na.action=na.omit)
Cand.set[[8]]<- glm(Fabalis~Nail_width,family=binomial,data=Bean1,na.action=na.omit)
Cand.set[[9]]<- glm(Fabalis~Bill_height,family=binomial,data=Bean1,na.action=na.omit)
Cand.set[[10]]<- glm(Fabalis~Bill_height_nail,family=binomial,data=Bean1,na.action=na.omit)
Cand.set[[11]]<- glm(Fabalis~Bill_height_nostril,family=binomial,data=Bean1,na.action=na.omit)
Cand.set[[12]]<- glm(Fabalis~Bill_width,family=binomial,data=Bean1,na.action=na.omit)
Cand.set[[13]]<- glm(Fabalis~Height_lower_mandible,family=binomial,data=Bean1,na.action=na.omit)
Cand.set[[14]]<- glm(Fabalis~Tail,family=binomial,data=Bean1,na.action=na.omit)
Cand.set[[15]]<- glm(Fabalis~Tarsus,family=binomial,data=Bean1,na.action=na.omit)
Cand.set[[16]]<- glm(Fabalis~Toe_nail,family=binomial,data=Bean1,na.action=na.omit)
Cand.set[[17]]<- glm(Fabalis~Teeth,family=binomial,data=Bean1,na.action=na.omit)
Cand.set[[18]]<- glm(Fabalis~Nail_shape,family=binomial,data=Bean1,na.action=na.omit)
Cand.set[[19]]<- glm(Fabalis~Culmen+Bill_height,family=binomial,data=Bean1,na.action=na.omit)
Cand.set[[20]]<- glm(Fabalis~Teeth+Height_lower_mandible,family=binomial,data=Bean1,na.action=na.omit)
Cand.set[[21]]<- glm(Fabalis~Teeth+Nail_shape,family=binomial,data=Bean1,na.action=na.omit)
names(Cand.set)<- c("Culmen","Lower mandible","Bill tip to nostril","Bill plus head",
                    "Head length","Head width","Nail length","Nail width","Bill height","Bill height nail",
                    "Bill height nostril","Bill width","Height lower mandible","Tail","Tarsus",
                    "Toe nail","Teeth","Nail shape","Culmen&Bill height","Teeth&Height lower mandible",
                    "Teeth&Nail_shape")
res.table2<-aictab(Cand.set,second.ord=TRUE, nobs=NULL, sort=TRUE, c.hat=1)
print(res.table2, digits=3, LL=TRUE)



###########################################################################################################
###########################################################################################################
## PART 2. Script used for all the analyses, even the ones not presented in the submitted manuscript 
###########################################################################################################
###########################################################################################################
##  
## Startup procedure and linking to libraries. 
## !Some libraries are initially blocket because they interfere with certain functions (mainly "histogram")
## They are activated later.
## The rm(list=ls()) command clears all the registers.

rm(list=ls())
library(lattice)
library(Matrix)
library(lme4)
library(MASS)
library(AICcmodavg)
library(corrplot)
#library(factoextra) Only needed for PCA
#library(ggplot2)  Only needed to support factoextra
citation("lattice")
citation("Matrix")
citation("lme4")
citation("MASS")
citation("AICcmodavg")
citation("corrplot")
#citation("ggplot2")
#citation("factoextra")

######################################################################################################

## Input data with full variable names (no classification variable)
Bean0<-read.table("l://AAStruktur/Sdgs/Subspec PCA/Goose measurements A.txt",header=TRUE,na.strings="NA")
names(Bean0)
Bean0$Teeth <- as.integer(Bean0$Teeth)

## Input data with abbreviated variable names (no classification variable)
Bean00<-read.table("l://AAStruktur/Sdgs/Subspec PCA/Goose measurements B.txt",header=TRUE,na.strings="NA")
names(Bean00)
Bean00$Q <- as.integer(Bean00$Q)

## Input data with with classification variable
Bean1<-read.table("l://AAStruktur/Sdgs/Subspec PCA/Goose measurements C.txt",header=TRUE,na.strings="NA")
names(Bean1)
Bean1$Teeth <- as.integer(Bean1$Teeth)

## Input data with with classification variable but only five explanatory variables. Used in discriminant analysis.
Bean1A<-read.table("l://AAStruktur/Sdgs/Subspec PCA/Goose measurements D.txt",header=TRUE,na.strings="NA")
names(Bean1A)
Bean1A$Teeth <- as.integer(Bean1A$Teeth)

## Input data with with classification variable but only two explanatory variables. Used in discriminant analysis.
Bean1B<-read.table("l://AAStruktur/Sdgs/Subspec PCA/Goose measurements E.txt",header=TRUE,na.strings="NA")
names(Bean1B)
Bean1B$Teeth <- as.integer(Bean1B$Teeth)


######################################################################################################
## SINGLE VARIABLE ANALYSES
######################################################################################################

## Basic statistics. I used a loop for this, but the variables can also be analysed one at a time.
attach(Bean0)
data.output <- NA
data.output= matrix(data=NA, nrow=17, ncol=8)
colnames(data.output)= c("i", "Antal","Minimum","Maximum", "Range", "Median", "Mean", "SD")
rader <- 1

for (i in 1:17)     #  loop for basic statistics per variable
{             # start loop i
  
  col1 <- NA
  col1 <- Bean00[,i]    # set the sample measurement value for each outer loop
  
  ## Set all support values to NA
  Min00 <- NA
  Max00 <- NA
  Mean00 <- NA
  Median00 <- NA
  SD00 <- NA
  Antal <- NA
  
  ## Do the calculations         
  Min00 <- min(col1)                 # assign the sub-set minimum to Min00 
  Max00 <- max(col1)                 # assign the sub-set maximum to Max00 
  Range00 <- (Max00 - Min00)
  Mean00 <- mean(col1)               # assign the sub-set average to Mean00 
  Median00 <-  median(col1)          # assign the sub-set median to Median00
  SD00  <- sd(col1)                  # assign the sub-set standard deviation to SD00
  Antal <- length(col1)
  
  data.output[rader , 1] = i            ##
  data.output[rader , 2] = Antal        ## 
  data.output[rader , 3] = Min00        ## 
  data.output[rader , 4] = Max00        ##   
  data.output[rader , 5] = Range00
  data.output[rader , 6] = Median00     ##
  data.output[rader , 7] = Mean00       ##       
  data.output[rader , 8] = SD00         ##  
  
  rader <- rader + 1
  
  
} ## close  loop


View(data.output)
## The data.output result table can be written to a file using: write.table(data.output, "file name.txt")

######################################################################################################

## Histograms
## Please note that the histogram function doesn't function when the ggplot2 package is activated

attach(Bean00)

histogram(Bean00$A, type="count", xlab="Culmen (mm)", col="grey")
histogram(Bean00$B, type="count", xlab="Lower mandible (mm)", col="grey")
histogram(Bean00$C, type="count", xlab="Bill tip to nostril (mm)", col="grey")
histogram(Bean00$D, type="count", xlab="Bill plus head (mm)", col="grey")
histogram(Bean00$E, type="count", xlab="Head length (mm)", col="grey")
histogram(Bean00$F, type="count", xlab="Head width (mm)", col="grey")
histogram(Bean00$G, type="count", xlab="Nail length (mm)", col="grey")
histogram(Bean00$H, type="count", xlab="Nail width (mm)", col="grey")
histogram(Bean00$I, type="count", xlab="Bill height (mm)", col="grey")
histogram(Bean00$J, type="count", xlab="Bill height nail (mm)", col="grey")
histogram(Bean00$K, type="count", xlab="Bill height nostril (mm)", col="grey")
histogram(Bean00$L, type="count", xlab="Bill width (mm)", col="grey")
histogram(Bean00$M, type="count", xlab="Height lower mandible (mm)", col="grey")
histogram(Bean00$N, type="count", xlab="Tail (mm)", col="grey")
histogram(Bean00$O, type="count", xlab="Tarsus (mm)", col="grey")
histogram(Bean00$P, type="count", xlab="Toe nail (mm)", col="grey")
histogram(Bean00$Q, type="count",breaks=seq(19.5,30.5,1), xlab="Teeth", col="grey")
######################################################################################################


######################################################################################################
# Logistic models and incidence plots for all individual variables

attach(Bean1)

## Logistic model for Culmen
MinA <- min(Bean1$Culmen)
MaxA <- max(Bean1$Culmen)
Form<-formula(Fabalis~Culmen)
MA<-glm(Form,family=binomial,data=Bean1,na.action=na.omit)
summary(MA)
xv<-seq(MinA,MaxA,0.1)
yv<-predict(MA,list(Culmen=xv),type="response")
plot(Culmen,Fabalis, xlab="Culmen (mm)")  
lines(xv,yv)

## Logistic model for Lower_mandible
MinB <- min(Bean1$Lower_mandible)
MaxB <- max(Bean1$Lower_mandible)
Form<-formula(Fabalis~Lower_mandible)
MB<-glm(Form,family=binomial,data=Bean1,na.action=na.omit)
summary(MB)
xv<-seq(MinB,MaxB,0.1)
yv<-predict(MB,list(Lower_mandible=xv),type="response")
plot(Lower_mandible,Fabalis, xlab="length of lower manidle (mm)")  
lines(xv,yv)

## Logistic model for Bill_tip_to_nostril
MinC <- min(Bean1$Bill_tip_to_nostril)
MaxC <- max(Bean1$Bill_tip_to_nostril)
Form<-formula(Fabalis~Bill_tip_to_nostril)
MC<-glm(Form,family=binomial,data=Bean1,na.action=na.omit)
summary(MC)
xv<-seq(MinC,MaxC,0.1)
yv<-predict(MC,list(Bill_tip_to_nostril=xv),type="response")
plot(Bill_tip_to_nostril,Fabalis, xlab="Bill tip to nostril (mm)")  
lines(xv,yv)

## Logistic model for Bill_plus_head
MinD <- min(Bean1$Bill_plus_head)
MaxD <- max(Bean1$Bill_plus_head)
Form<-formula(Fabalis~Bill_plus_head)
MD<-glm(Form,family=binomial,data=Bean1,na.action=na.omit)
summary(MD)
xv<-seq(MinD,MaxD,0.1)
yv<-predict(MD,list(Bill_plus_head=xv),type="response")
plot(Bill_plus_head,Fabalis, xlab="length of bill and head (mm)")  
lines(xv,yv)

## Logistic model for Head_length
MinE <- min(Bean1$Head_length)
MaxE <- max(Bean1$Head_length)
Form<-formula(Fabalis~Head_length)
ME<-glm(Form,family=binomial,data=Bean1,na.action=na.omit)
summary(ME)
xv<-seq(MinE,MaxE,0.1)
yv<-predict(ME,list(Head_length=xv),type="response")
plot(Head_length,Fabalis)  
lines(xv,yv)

## Logistic model for Head_width
MinF <- min(Bean1$Head_width)
MaxF <- max(Bean1$Head_width)
Form<-formula(Fabalis~Head_width)
MF<-glm(Form,family=binomial,data=Bean1,na.action=na.omit)
summary(MF)
xv<-seq(MinF,MaxF,0.1)
yv<-predict(MF,list(Head_width=xv),type="response")
plot(Head_width,Fabalis)  
lines(xv,yv)

## Logistic model for Nail_length
MinG <- min(Bean1$Nail_length)
MaxG <- max(Bean1$Nail_length)
Form<-formula(Fabalis~Nail_length)
MG<-glm(Form,family=binomial,data=Bean1,na.action=na.omit)
summary(MG)
xv<-seq(MinG,MaxG,0.1)
yv<-predict(MG,list(Nail_length=xv),type="response")
plot(Nail_length,Fabalis)  
lines(xv,yv)

## Logistic model for Nail_width
MinH <- min(Bean1$Nail_width)
MaxH <- max(Bean1$Nail_width)
Form<-formula(Fabalis~Nail_width)
MH<-glm(Form,family=binomial,data=Bean1,na.action=na.omit)
summary(MH)
xv<-seq(MinH,MaxH,0.1)
yv<-predict(MH,list(Nail_width=xv),type="response")
plot(Nail_width,Fabalis)  
lines(xv,yv)

## Logistic model for Bill_height
MinI <- min(Bean1$Bill_height)
MaxI <- max(Bean1$Bill_height)
Form<-formula(Fabalis~Bill_height)
MI<-glm(Form,family=binomial,data=Bean1,na.action=na.omit)
summary(MI)
xv<-seq(MinI,MaxI,0.1)
yv<-predict(MI,list(Bill_height=xv),type="response")
plot(Bill_height,Fabalis)  
lines(xv,yv)

## Logistic model for Bill_height_nail
MinJ <- min(Bean1$Bill_height_nail)
MaxJ <- max(Bean1$Bill_height_nail)
Form<-formula(Fabalis~Bill_height_nail)
MJ<-glm(Form,family=binomial,data=Bean1,na.action=na.omit)
summary(MJ)
xv<-seq(MinJ,MaxJ,0.1)
yv<-predict(MJ,list(Bill_height_nail=xv),type="response")
plot(Bill_height_nail,Fabalis)  
lines(xv,yv)

## Logistic model for Bill_height_nostril
MinK <- min(Bean1$Bill_height_nostril)
MaxK <- max(Bean1$Bill_height_nostril)
Form<-formula(Fabalis~Bill_height_nostril)
MK<-glm(Form,family=binomial,data=Bean1,na.action=na.omit)
summary(MK)
xv<-seq(MinK,MaxK,0.1)
yv<-predict(MK,list(Bill_height_nostril=xv),type="response")
plot(Bill_height_nostril,Fabalis)  
lines(xv,yv)

## Logistic model for Bill_width
MinL <- min(Bean1$Bill_width)
MaxL <- max(Bean1$Bill_width)
Form<-formula(Fabalis~Bill_width)
ML<-glm(Form,family=binomial,data=Bean1,na.action=na.omit)
summary(ML)
xv<-seq(MinL,MaxL,0.1)
yv<-predict(ML,list(Bill_width=xv),type="response")
plot(Bill_width,Fabalis)  
lines(xv,yv)

## Logistic model for Height_lower_mandible
MinM <- min(Bean1$Height_lower_mandible)
MaxM <- max(Bean1$Height_lower_mandible)
Form<-formula(Fabalis~Height_lower_mandible)
MM<-glm(Form,family=binomial,data=Bean1,na.action=na.omit)
summary(MM)
xv<-seq(MinM,MaxM,0.01)
yv<-predict(MM,list(Height_lower_mandible=xv),type="response")
plot(Height_lower_mandible,Fabalis, xlab="Height lower mandible (mm)")  
lines(xv,yv)

## Logistic model for Tail
MinN <- min(Bean1$Tail)
MaxN <- max(Bean1$Tail)
Form<-formula(Fabalis~Tail)
MN<-glm(Form,family=binomial,data=Bean1,na.action=na.omit)
summary(MN)
xv<-seq(MinN,MaxN,0.1)
yv<-predict(MN,list(Tail=xv),type="response")
plot(Tail,Fabalis)  
lines(xv,yv)

## Logistic model for Tarsus
MinO <- min(Bean1$Tarsus)
MaxO <- max(Bean1$Tarsus)
Form<-formula(Fabalis~Tarsus)
MO<-glm(Form,family=binomial,data=Bean1,na.action=na.omit)
summary(MO)
xv<-seq(MinO,MaxO,0.1)
yv<-predict(MO,list(Tarsus=xv),type="response")
plot(Tarsus,Fabalis)  
lines(xv,yv)

## Logistic model for Toe_nail
MinP <- min(Bean1$Toe_nail)
MaxP <- max(Bean1$Toe_nail)
Form<-formula(Fabalis~Toe_nail)
MP<-glm(Form,family=binomial,data=Bean1,na.action=na.omit)
summary(MP)
xv<-seq(MinP,MaxP,0.1)
yv<-predict(MP,list(Toe_nail=xv),type="response")
plot(Toe_nail,Fabalis)  
lines(xv,yv)

## Logistic model for Teeth
MinQ <- min(Bean1$Teeth)
MaxQ <- max(Bean1$Teeth)
Form<-formula(Fabalis~Teeth)
MQ<-glm(Form,family=binomial,data=Bean1,na.action=na.omit)
summary(MQ)
xv<-seq(MinQ,MaxQ,0.1)
yv<-predict(MQ,list(Teeth=xv),type="response")
plot(Teeth,Fabalis, xlab="Number of teeth in upper mandible")  
lines(xv,yv)


######################################################################################################
##AICc values for all single variable logistic models
AICc(MA, return.K = FALSE, second.ord = TRUE, nobs = NULL, c.hat = 1)
AICc(MB, return.K = FALSE, second.ord = TRUE, nobs = NULL, c.hat = 1)
AICc(MC, return.K = FALSE, second.ord = TRUE, nobs = NULL, c.hat = 1)
AICc(MD, return.K = FALSE, second.ord = TRUE, nobs = NULL, c.hat = 1)
AICc(ME, return.K = FALSE, second.ord = TRUE, nobs = NULL, c.hat = 1)
AICc(MF, return.K = FALSE, second.ord = TRUE, nobs = NULL, c.hat = 1)
AICc(MG, return.K = FALSE, second.ord = TRUE, nobs = NULL, c.hat = 1)
AICc(MH, return.K = FALSE, second.ord = TRUE, nobs = NULL, c.hat = 1)
AICc(MI, return.K = FALSE, second.ord = TRUE, nobs = NULL, c.hat = 1)
AICc(MJ, return.K = FALSE, second.ord = TRUE, nobs = NULL, c.hat = 1)
AICc(MK, return.K = FALSE, second.ord = TRUE, nobs = NULL, c.hat = 1)
AICc(ML, return.K = FALSE, second.ord = TRUE, nobs = NULL, c.hat = 1)
AICc(MM, return.K = FALSE, second.ord = TRUE, nobs = NULL, c.hat = 1)
AICc(MN, return.K = FALSE, second.ord = TRUE, nobs = NULL, c.hat = 1)
AICc(MO, return.K = FALSE, second.ord = TRUE, nobs = NULL, c.hat = 1)
AICc(MP, return.K = FALSE, second.ord = TRUE, nobs = NULL, c.hat = 1)
AICc(MQ, return.K = FALSE, second.ord = TRUE, nobs = NULL, c.hat = 1)
######################################################################################################


######################################################################################################
## Pairwise VARIABLE ANALYSES
######################################################################################################

## Pairs plot
## With full names (should be avoided in cases with many variables and long names)
#pairs(Bean0)


######################################################################################################
## Pairs plot with abbreviated names and smoother
attach(Bean00)
par(mfrow=c(1,1))

par(mfrow=c(1,1))
pairs(Bean00,panel=panel.smooth)

######################################################################################################
### Correlation matrix with full variable names (should be avoided here)
#M01<-cor(Bean0)
#corrplot.mixed(M01)

######################################################################################################
### Correlation matrix with abbreviated variable names
attach(Bean00)
par(mfrow=c(1,1))

par(mfrow=c(1,1))
M02<-cor(Bean00)
corrplot.mixed(M02, lower.col="black", number.cex=0.7)


######################################################################################################
## partitioning (kmeans)
## Applying kmeans to all pairs of variables would be a huge effort. These are just two examples.
######################################################################################################

attach(Bean1)
par(mfrow=c(2,2))

plot(Bean1$Culmen,Bean1$Height_lower_mandible, col=c(Bean1$Fabalis+1),pch=16, ylab="Height lower mandible (mm)", xlab="Culmen (mm)")
MP2 <- kmeans(data.frame(Culmen,Height_lower_mandible),2)
plot(Bean1$Culmen,Bean1$Height_lower_mandible,col=MP2[[1]],pch=16, ylab="Height lower mandible (mm)", xlab="Culmen (mm)")
table(MP2[[1]], Fabalis)

plot(Bean1$Teeth,Bean1$Height_lower_mandible, col=c(Bean1$Fabalis+1),pch=16, ylab="Height lower mandible (mm)", xlab="Teeth")
MP2 <- kmeans(data.frame(Teeth,Height_lower_mandible),2)
plot(Bean1$Teeth,Bean1$Height_lower_mandible,col=MP2[[1]],pch=16, ylab="Height lower mandible (mm)", xlab="Teeth")
table(MP2[[1]], Fabalis)
par(mfrow=c(1,1))

######################################################################################################


######################################################################################################
## Multiple VARIABLE ANALYSES
######################################################################################################


######################################################################################################
### Discriminant analysis with all variables and full variable names
attach(Bean1)
par(mfrow=c(1,1))

MDisc<-lda(Fabalis~.,Bean1)
plot(MDisc, col="grey")
summary(MDisc)
MDisc

######################################################################################################

### Discriminant analysis with only five variables (LD1 > 0.1)
MDisc5<-lda(Fabalis~.,Bean1A)
plot(MDisc5, col="grey")
MDisc5
######################################################################################################

### Discriminant analysis with only two variables
MDisc2<-lda(Fabalis~.,Bean1B)
plot(MDisc2, col="grey")
MDisc2
######################################################################################################

######################################################################################################
## Model selection with single variable models
######################################################################################################
attach(Bean1)

res.table1<-NA
Cand.set<-list()
Cand.set[[1]]<- glm(Fabalis~Culmen,family=binomial,data=Bean1,na.action=na.omit)
Cand.set[[2]]<- glm(Fabalis~Lower_mandible,family=binomial,data=Bean1,na.action=na.omit)
Cand.set[[3]]<- glm(Fabalis~Bill_tip_to_nostril,family=binomial,data=Bean1,na.action=na.omit)
Cand.set[[4]]<- glm(Fabalis~Bill_plus_head,family=binomial,data=Bean1,na.action=na.omit)
Cand.set[[5]]<- glm(Fabalis~Head_length,family=binomial,data=Bean1,na.action=na.omit)
Cand.set[[6]]<- glm(Fabalis~Head_width,family=binomial,data=Bean1,na.action=na.omit)
Cand.set[[7]]<- glm(Fabalis~Nail_length,family=binomial,data=Bean1,na.action=na.omit)
Cand.set[[8]]<- glm(Fabalis~Nail_width,family=binomial,data=Bean1,na.action=na.omit)
Cand.set[[9]]<- glm(Fabalis~Bill_height,family=binomial,data=Bean1,na.action=na.omit)
Cand.set[[10]]<- glm(Fabalis~Bill_height_nail,family=binomial,data=Bean1,na.action=na.omit)
Cand.set[[11]]<- glm(Fabalis~Bill_height_nostril,family=binomial,data=Bean1,na.action=na.omit)
Cand.set[[12]]<- glm(Fabalis~Bill_width,family=binomial,data=Bean1,na.action=na.omit)
Cand.set[[13]]<- glm(Fabalis~Height_lower_mandible,family=binomial,data=Bean1,na.action=na.omit)
Cand.set[[14]]<- glm(Fabalis~Tail,family=binomial,data=Bean1,na.action=na.omit)
Cand.set[[15]]<- glm(Fabalis~Tarsus,family=binomial,data=Bean1,na.action=na.omit)
Cand.set[[16]]<- glm(Fabalis~Toe_nail,family=binomial,data=Bean1,na.action=na.omit)
Cand.set[[17]]<- glm(Fabalis~Teeth,family=binomial,data=Bean1,na.action=na.omit)
names(Cand.set)<- c("Culmen","Lower mandible","Bill tip to nostril","Bill plus head",
                    "Head length","Head width","Nail length","Nail width","Bill height","Bill height nail",
                    "Bill height nostril","Bill width","Height lower mandible","Tail","Tarsus",
                    "Toe nail","Teeth")
res.table1<-aictab(Cand.set,second.ord=TRUE, nobs=NULL, sort=TRUE, c.hat=1)
print(res.table1, digits=3, LL=TRUE)

######################################################################################################
## Model selection with variable combinations and a composite variable (models 18-21)
######################################################################################################
attach(Bean1)
Bean1$Nail_shape<-(Bean1$Nail_length/Bean1$Nail_width) ## Creates the nail-shape variable

res.table2<-NA
Cand.set<-list()
Cand.set[[1]]<- glm(Fabalis~Culmen,family=binomial,data=Bean1,na.action=na.omit)
Cand.set[[2]]<- glm(Fabalis~Lower_mandible,family=binomial,data=Bean1,na.action=na.omit)
Cand.set[[3]]<- glm(Fabalis~Bill_tip_to_nostril,family=binomial,data=Bean1,na.action=na.omit)
Cand.set[[4]]<- glm(Fabalis~Bill_plus_head,family=binomial,data=Bean1,na.action=na.omit)
Cand.set[[5]]<- glm(Fabalis~Head_length,family=binomial,data=Bean1,na.action=na.omit)
Cand.set[[6]]<- glm(Fabalis~Head_width,family=binomial,data=Bean1,na.action=na.omit)
Cand.set[[7]]<- glm(Fabalis~Nail_length,family=binomial,data=Bean1,na.action=na.omit)
Cand.set[[8]]<- glm(Fabalis~Nail_width,family=binomial,data=Bean1,na.action=na.omit)
Cand.set[[9]]<- glm(Fabalis~Bill_height,family=binomial,data=Bean1,na.action=na.omit)
Cand.set[[10]]<- glm(Fabalis~Bill_height_nail,family=binomial,data=Bean1,na.action=na.omit)
Cand.set[[11]]<- glm(Fabalis~Bill_height_nostril,family=binomial,data=Bean1,na.action=na.omit)
Cand.set[[12]]<- glm(Fabalis~Bill_width,family=binomial,data=Bean1,na.action=na.omit)
Cand.set[[13]]<- glm(Fabalis~Height_lower_mandible,family=binomial,data=Bean1,na.action=na.omit)
Cand.set[[14]]<- glm(Fabalis~Tail,family=binomial,data=Bean1,na.action=na.omit)
Cand.set[[15]]<- glm(Fabalis~Tarsus,family=binomial,data=Bean1,na.action=na.omit)
Cand.set[[16]]<- glm(Fabalis~Toe_nail,family=binomial,data=Bean1,na.action=na.omit)
Cand.set[[17]]<- glm(Fabalis~Teeth,family=binomial,data=Bean1,na.action=na.omit)
Cand.set[[18]]<- glm(Fabalis~Nail_shape,family=binomial,data=Bean1,na.action=na.omit)
Cand.set[[19]]<- glm(Fabalis~Culmen+Bill_height,family=binomial,data=Bean1,na.action=na.omit)
Cand.set[[20]]<- glm(Fabalis~Teeth+Height_lower_mandible,family=binomial,data=Bean1,na.action=na.omit)
Cand.set[[21]]<- glm(Fabalis~Teeth+Nail_shape,family=binomial,data=Bean1,na.action=na.omit)
names(Cand.set)<- c("Culmen","Lower mandible","Bill tip to nostril","Bill plus head",
                    "Head length","Head width","Nail length","Nail width","Bill height","Bill height nail",
                    "Bill height nostril","Bill width","Height lower mandible","Tail","Tarsus",
                    "Toe nail","Teeth","Nail shape","Culmen&Bill height","Teeth&Height lower mandible",
                    "Teeth&Nail_shape")
res.table2<-aictab(Cand.set,second.ord=TRUE, nobs=NULL, sort=TRUE, c.hat=1)
print(res.table2, digits=3, LL=TRUE)


###########################################################################################################
## IN case you want to use Principle Component Analysis for this dataset (which I avoided) the following should work:
######################################################################################################
### Principle component analysis with all variables and full variable names

library(factoextra)
library(ggplot2)

attach(Bean0)
MPCA1 <- NA
MPCA1<-prcomp(Bean0, scale=TRUE)
summary(MPCA1)
plot(MPCA1, col="grey") ## Scree plot
fviz_pca_var(MPCA1, col.var="contrib", gradient.cols = c("#00AFBB", "#E7B800", "#FC4E07"),
             repel = TRUE     # Avoid text overlapping
) ## plot of variable loadings
fviz_pca_ind(MPCA1, labels = FALSE, col.ind=Bean1$Fabalis, gradient.cols = c(1,2)) ## plot of individuals

###########################################################################################################
## IN case you want to use hierarchical cluster analysis for this dataset (which I avoided) the following should work:
######################################################################################################

### Hierarchical cluster analysis
attach(Bean1)
Clust01<- hclust(dist(Bean1[,2:18]))
plot(Clust01,labels=(Fabalis), main="Hierarchical Cluster analysis")
summary(Clust01)






###########################################################################################################
###########################################################################################################
## PART 3. Generalised Script for the whole screening session
###########################################################################################################
###########################################################################################################
## !Some libraries are initially blocket because they interfere with certain functions (mainly "histogram")
## They are activated later.

rm(list=ls())
library(lattice)
library(Matrix)
library(lme4)
library(MASS)
library(AICcmodavg)
library(corrplot)
#library(ggplot2)
#library(factoextra)
library(stats)
citation("lattice")
citation("Matrix")
citation("lme4")
citation("MASS")
citation("AICcmodavg")
citation("corrplot")
#citation("ggplot2")
##citation("factoextra")

######################################################################################################
## Input of datafiles
######################################################################################################
## Dataframe Meas1 is assumed to include a response variable, while Meas does not.
## In this example of read.table, two different files are used, but Meas can easily be created from Meas1

Meas<-read.table("x://FILENAME.txt",header=TRUE,na.strings="NA")
names(Meas)

Meas1<-read.table("x://FILENAME.txt",header=TRUE,na.strings="NA")
names(Meas1)

######################################################################################################
## SINGLE VARIABLE ANALYSES
######################################################################################################

## Basic statistics (for all explanatory variables using a loop)
## Minimum, maximum, range, mean, Standard deviation (SD) and Median values for individual variables 

attach(Meas)

data.output <- NA
data.output= matrix(data=NA, nrow=17, ncol=8)
colnames(data.output)= c("i", "Antal","Minimum","Maximum", "Range", "Median", "Mean", "SD")
rader <- 1

for (i in 1:17)     #  loop for basic statistics per variable
{             # start loop i
  
  col1 <- NA
  col1 <- Meas[,i]    #chose the variable = column
  
  ## Set all support values to NA
  Min00 <- NA
  Max00 <- NA
  Mean00 <- NA
  Median00 <- NA
  SD00 <- NA
  Antal <- NA
  
  ## Do the calculations         
  Min00 <- min(col1)                 # assign the minimum to Min00 
  Max00 <- max(col1)                 # assign the maximum to Max00 
  Range00 <- (Max00 - Min00)
  Mean00 <- mean(col1)               # assign the average to Mean00 
  Median00 <-  median(col1)          # assign the median to Median00
  SD00  <- sd(col1)                  # assign the standard deviation to SD00
  Antal <- length(col1)
  
  data.output[rader , 1] = i            ##
  data.output[rader , 2] = Antal        ## 
  data.output[rader , 3] = Min00        ## 
  data.output[rader , 4] = Max00        ##   
  data.output[rader , 5] = Range00
  data.output[rader , 6] = Median00     ##
  data.output[rader , 7] = Mean00       ##       
  data.output[rader , 8] = SD00         ##  
  
  rader <- rader + 1
  
  
} ## close  loop


View(data.output)
## The data.output result table can be written to a file using: write.table(data.output, "file name.txt")

######################################################################################################

## Histograms
## Please note that the histogram function doesn't work when the ggplot2 package is activated
attach(Meas)
histogram(Meas$VarX, type="count", xlab="TEXT", col="grey")

######################################################################################################
## Logistic model and incidence plot
attach(Meas1)  # The dataset needs to include a binary response variable (VarY) and one or more explanatory variables of which VarX is used here

MinQ <- min(Meas1$VarX)
MaxQ <- max(Meas1$VarX)
Form<-formula(Meas1$VarY~Meas1$VarX)
MA<-glm(Form,family=binomial,data=Meas1,na.action=na.omit)
summary(MQ)
xv<-seq(MinQ,MaxQ,0.1)
yv<-predict(MQ,list(VarX=xv),type="response")
plot(VarX,VarY, xlab="Label x-axis")  
lines(xv,yv)

######################################################################################################
##AIC values for all  single variable logistic models
AIC(MA)


######################################################################################################
## Pairwise VARIABLE ANALYSES
######################################################################################################

######################################################################################################
## Pairs plot with smoother
attach(Meas)
par(mfrow=c(1,1))

pairs(Meas,panel=panel.smooth)

## Detailed plots of observation on two variables (exaple)
plot(Meas$A, Meas$B)

######################################################################################################

### Correlation matrix 
attach(Meas)
par(mfrow=c(1,1))

Mcm<-cor(Meas)
corrplot.mixed(Mcm, lower.col="black", number.cex=0.7)



######################################################################################################
## partitioning (kmeans)
######################################################################################################

attach(Meas1)
par(mfrow=c(1,2))

plot(Meas1$VarX,Meas1$VarY, col=c(Meas1$Resp+1),pch=16, ylab="Y label", xlab="X label")
Mkm <- kmeans(data.frame(VarX,VarY),2)   ## the number 2 stands for the number of clusters kmeans will make
plot(Meas1$VarX,Meas1$VarY,col=MP2[[1]],pch=16, ylab="Y label", xlab="X label")
table(Mkm[[1]], Resp)

######################################################################################################


######################################################################################################
## Multiple VARIABLE ANALYSES
######################################################################################################

######################################################################################################
### Discriminant analysis with all variables and full variable names
attach(Meas1)
par(mfrow=c(1,1))

MDisc<-lda(Resp~.,Meas1)   ## "Resp" = name of the response variable
plot(MDisc, col="grey")
summary(MDisc)
MDisc

######################################################################################################

######################################################################################################
## Model selection with single variable models
######################################################################################################
attach(Meas1)

res.table1<-NA   #more variables can be added and named
Cand.set<-list()
Cand.set[[1]]<- glm(Resp~VarX1,family=binomial,data=Meas1,na.action=na.omit)
Cand.set[[2]]<- glm(Resp~VarX2,family=binomial,data=Meas1,na.action=na.omit)
names(Cand.set)<- c("Var.name1","Var.name2")
res.table1<-aictab(Cand.set,second.ord=TRUE, nobs=NULL, sort=TRUE, c.hat=1)
print(res.table1, digits=3, LL=TRUE)


######################################################################################################
### Principle component analysis with all variables
library(factoextra)
library(ggplot2)

attach(Meas1)
par(mfrow=c(1,1))

MPCA1 <- NA
MPCA1<-prcomp(Meas1, scale=TRUE)
summary(MPCA1)
plot(MPCA1, col="grey")
fviz_pca_var(MPCA1, col.var="contrib", gradient.cols = c("#00AFBB", "#E7B800", "#FC4E07"),
             repel = TRUE   
)
fviz_pca_ind(MPCA1, labels = FALSE, col.ind=Bean1$Fabalis, gradient.cols = c(1,2))
## this last line of code needs categori codes (variable Resp from a dataframe with the response varaible) 
## for color coding the individuals in the PCA plot. Here marked with "Bean1$Fabalis" from the bean goose
## measurement script.


